@@ -21,12 +21,16 @@ package org.apache.cxf.jaxrs.provider;
 
 import java.lang.annotation.Annotation;
 import java.lang.reflect.Type;
+import java.util.List;
 import java.util.Map;
+import java.util.ResourceBundle;
 import java.util.WeakHashMap;
 import java.util.logging.Logger;
 
+import javax.ws.rs.WebApplicationException;
 import javax.ws.rs.core.Context;
 import javax.ws.rs.core.MediaType;
+import javax.ws.rs.core.Response;
 import javax.ws.rs.ext.ContextResolver;
 import javax.ws.rs.ext.MessageBodyReader;
 import javax.ws.rs.ext.MessageBodyWriter;
@@ -34,26 +38,33 @@ import javax.xml.bind.JAXBContext;
 import javax.xml.bind.JAXBElement;
 import javax.xml.bind.JAXBException;
 import javax.xml.bind.Marshaller;
+import javax.xml.bind.Unmarshaller;
 import javax.xml.bind.annotation.XmlRootElement;
 import javax.xml.bind.annotation.adapters.XmlAdapter;
 import javax.xml.bind.annotation.adapters.XmlJavaTypeAdapter;
+import javax.xml.validation.Schema;
 
+import org.apache.cxf.common.i18n.BundleUtils;
 import org.apache.cxf.common.logging.LogUtils;
 import org.apache.cxf.common.util.PackageUtils;
 import org.apache.cxf.jaxrs.utils.AnnotationUtils;
 import org.apache.cxf.jaxrs.utils.InjectionUtils;
+import org.apache.cxf.jaxrs.utils.schemas.SchemaHandler;
 
-public abstract class AbstractJAXBProvider 
+public abstract class AbstractJAXBProvider extends AbstractConfigurableProvider
     implements MessageBodyReader<Object>, MessageBodyWriter<Object> {
     
+    protected static final ResourceBundle BUNDLE = BundleUtils.getBundle(AbstractJAXBProvider.class);
+       
     private static final Logger LOG = LogUtils.getL7dLogger(AbstractJAXBProvider.class);
 
     private static final String CHARSET_PARAMETER = "charset"; 
-
+        
     private static Map<String, JAXBContext> packageContexts = new WeakHashMap<String, JAXBContext>();
     private static Map<Class<?>, JAXBContext> classContexts = new WeakHashMap<Class<?>, JAXBContext>();
-    
+        
     @Context protected ContextResolver<JAXBContext> resolver;
+    private Schema schema;
     
     public boolean isWriteable(Class<?> type, Type genericType, Annotation[] anns) {
         return isSupported(type, genericType, anns)
@@ -64,10 +75,19 @@ public abstract class AbstractJAXBProvider
         return isSupported(type, genericType, annotations);
     }
 
+    public void setSchemaLocations(List<String> locations) {
+        schema = SchemaHandler.createSchema(locations);    
+    }
+    
     public long getSize(Object o) {
         return -1;
     }
 
+    public void setSchema(Schema s) {
+        schema = s;    
+    }
+ 
+
     protected JAXBContext getJAXBContext(Class<?> type, Type genericType) throws JAXBException {
         
         if (resolver != null) {
@@ -97,7 +117,7 @@ public abstract class AbstractJAXBProvider
         synchronized (classContexts) {
             JAXBContext context = classContexts.get(type);
             if (context == null) {
-                context = JAXBContext.newInstance(type);
+                context = JAXBContext.newInstance(new Class[]{type});
                 classContexts.put(type, context);
             }
             return context;
@@ -148,6 +168,16 @@ public abstract class AbstractJAXBProvider
         return objectFactoryForClass(InjectionUtils.getActualType(genericType));
     }
     
+    protected Unmarshaller createUnmarshaller(Class<?> cls, Type genericType) 
+        throws JAXBException {
+        JAXBContext context = getJAXBContext(cls, genericType);
+        Unmarshaller unmarshaller = context.createUnmarshaller();
+        if (schema != null) {
+            unmarshaller.setSchema(schema);
+        }
+        return unmarshaller;        
+    }
+    
     protected Marshaller createMarshaller(Object obj, Class<?> cls, Type genericType, MediaType m)
         throws JAXBException {
         
@@ -187,4 +217,18 @@ public abstract class AbstractJAXBProvider
         }
         return obj;
     }
+    
+    protected Schema getSchema() {
+        return schema;
+    }
+    
+    protected static void handleJAXBException(JAXBException e) {
+        Throwable t = e.getLinkedException() != null 
+            ? e.getLinkedException() : e.getCause() != null ? e.getCause() : e;
+        String message = new org.apache.cxf.common.i18n.Message("JAXB_EXCEPTION", 
+                             BUNDLE, t.getMessage()).toString();
+        Response r = Response.status(Response.Status.INTERNAL_SERVER_ERROR)
+            .type(MediaType.TEXT_PLAIN).entity(message).build();
+        throw new WebApplicationException(t, r);
+    }
 }
