@@ -304,7 +304,9 @@ public class ReflectionServiceFactoryBean extends AbstractServiceFactoryBean {
     }
     
     protected void buildServiceFromWSDL(String url) {
-        LOG.info("Creating Service " + getServiceQName() + " from WSDL: " + url);
+        if (LOG.isLoggable(Level.FINE)) {
+            LOG.fine("Creating Service " + getServiceQName() + " from WSDL: " + url);
+        }
         populateFromClass = false;
         WSDLServiceFactory factory = new WSDLServiceFactory(getBus(), url, getServiceQName());
         setService(factory.create());
@@ -323,7 +325,9 @@ public class ReflectionServiceFactoryBean extends AbstractServiceFactoryBean {
     }
 
     protected void buildServiceFromClass() {
-        LOG.info("Creating Service " + getServiceQName() + " from class " + getServiceClass().getName());
+        if (LOG.isLoggable(Level.FINE)) {
+            LOG.fine("Creating Service " + getServiceQName() + " from class " + getServiceClass().getName());
+        }
         populateFromClass = true;
 
         if (Proxy.isProxyClass(this.getServiceClass())) {
@@ -549,7 +553,7 @@ public class ReflectionServiceFactoryBean extends AbstractServiceFactoryBean {
 
         if (initializeClassInfo(o, method, op == null ? null
             : CastUtils.cast(op.getParameterOrdering(), String.class))) {
-            getMethodDispatcher().bind(o, method);
+            bindOperation(o, method);
             o.setProperty(ReflectionServiceFactoryBean.METHOD, method);
         } else {
             LOG.log(Level.WARNING, "NO_METHOD_FOR_OP", o.getName());
@@ -796,10 +800,14 @@ public class ReflectionServiceFactoryBean extends AbstractServiceFactoryBean {
             createMessageParts(intf, op, m);
         }
 
-        getMethodDispatcher().bind(op, m);
+        bindOperation(op, m);
 
         return op;
     }
+    
+    protected void bindOperation(OperationInfo op, Method m) {
+        getMethodDispatcher().bind(op, m);
+    }
 
     protected void initializeWrappedSchema(ServiceInfo serviceInfo) {
         for (OperationInfo op : serviceInfo.getInterface().getOperations()) {
@@ -995,7 +1003,7 @@ public class ReflectionServiceFactoryBean extends AbstractServiceFactoryBean {
 
             if (mpi.isElement()) {
                 XmlSchemaElement oldEl = (XmlSchemaElement)mpi.getXmlSchema();
-                if (!oldEl.getQName().equals(qname)) {
+                if (null != oldEl && !oldEl.getQName().equals(qname)) {
                     el.setSchemaTypeName(oldEl.getSchemaTypeName());
                     el.setSchemaType(oldEl.getSchemaType());
                     if (oldEl.getSchemaTypeName() != null) {
@@ -2044,6 +2052,35 @@ public class ReflectionServiceFactoryBean extends AbstractServiceFactoryBean {
 
     public void setServiceClass(Class<?> serviceClass) {
         this.serviceClass = serviceClass;
+        checkServiceClassAnnotations(serviceClass);
+    }
+    protected void checkServiceClassAnnotations(Class<?> sc) {
+        Annotation anns[] = serviceClass.getAnnotations();
+        if (anns != null) {
+            for (Annotation ann : anns) {
+                String pkg = ann.annotationType().getPackage().getName(); 
+                if ("javax.xml.ws".equals(pkg)
+                    || "javax.jws".equals(pkg)) {
+                    
+                    LOG.log(Level.WARNING, "JAXWS_ANNOTATION_FOUND", serviceClass.getName());
+                    return;
+                }
+            }
+        }
+        for (Method m : serviceClass.getMethods()) {
+            anns = m.getAnnotations();
+            if (anns != null) {
+                for (Annotation ann : anns) {
+                    String pkg = ann.annotationType().getPackage().getName(); 
+                    if ("javax.xml.ws".equals(pkg)
+                        || "javax.jws".equals(pkg)) {
+                        
+                        LOG.log(Level.WARNING, "JAXWS_ANNOTATION_FOUND", serviceClass.getName());
+                        return;
+                    }
+                }
+            }
+        }
     }
 
     public String getWsdlURL() {
