@@ -28,7 +28,9 @@ import java.net.HttpURLConnection;
 import java.net.URISyntaxException;
 import java.net.URL;
 import java.net.URLEncoder;
+import java.util.ArrayList;
 import java.util.HashMap;
+import java.util.List;
 import java.util.Map;
 import java.util.concurrent.ExecutionException;
 import java.util.concurrent.Executor;
@@ -49,8 +51,6 @@ import javax.xml.xpath.XPathConstants;
 import org.w3c.dom.Document;
 import org.w3c.dom.Node;
 
-import com.sun.xml.bind.api.JAXBRIContext;
-
 import org.apache.cxf.Bus;
 import org.apache.cxf.binding.soap.Soap11;
 import org.apache.cxf.bus.CXFBusFactory;
@@ -74,6 +74,7 @@ import org.apache.hello_world_soap_http.SOAPServiceDocLitBare;
 import org.apache.hello_world_soap_http.SOAPServiceMultiPortTypeTest;
 import org.apache.hello_world_soap_http.types.BareDocumentResponse;
 import org.apache.hello_world_soap_http.types.GreetMeLaterResponse;
+import org.apache.hello_world_soap_http.types.GreetMeResponse;
 import org.junit.BeforeClass;
 import org.junit.Test;
 
@@ -105,7 +106,7 @@ public class ClientServerTest extends AbstractBusClientServerTestBase {
 
     @Test
     public void testBase64() throws URISyntaxException  {
-        URL wsdl = getClass().getResource("/wsdl/dynamic_client_base64.wsdl");
+        URL wsdl = getClass().getResource("/wsdl/others/dynamic_client_base64.wsdl");
         assertNotNull(wsdl);
         String wsdlUrl = null;
         wsdlUrl = wsdl.toURI().toString();
@@ -115,6 +116,20 @@ public class ClientServerTest extends AbstractBusClientServerTestBase {
         Client client = dynamicClientFactory.createClient(wsdlUrl);
         assertNotNull(client);
     }
+    
+    @Test
+    public void testJaxWsDynamicClient() throws Exception {
+        URL wsdl = getClass().getResource("/wsdl/others/dynamic_client_base64.wsdl");
+        assertNotNull(wsdl);
+        String wsdlUrl = null;
+        wsdlUrl = wsdl.toURI().toString();
+        CXFBusFactory busFactory = new CXFBusFactory(); 
+        Bus bus = busFactory.createBus();
+        org.apache.cxf.jaxws.endpoint.dynamic.JaxWsDynamicClientFactory dynamicClientFactory = 
+            org.apache.cxf.jaxws.endpoint.dynamic.JaxWsDynamicClientFactory.newInstance(bus);
+        Client client = dynamicClientFactory.createClient(wsdlUrl);
+        assertNotNull(client);
+    }
         
     @Test
     public void testBasicConnection() throws Exception {
@@ -485,16 +500,17 @@ public class ClientServerTest extends AbstractBusClientServerTestBase {
         
         
         assertEquals(((TestExecutor)executor).getCount(), 0);
-        try {
-            Greeter greeter = (Greeter)service.getPort(portName, Greeter.class);
-            for (int i = 0; i < 5; i++) {
-                greeter.greetMeAsync("asyn call" + i);
-            }
-        } catch (UndeclaredThrowableException ex) {
-            throw (Exception)ex.getCause();
+        Greeter greeter = (Greeter)service.getPort(portName, Greeter.class);
+        List<Response<GreetMeResponse>> responses = new ArrayList<Response<GreetMeResponse>>();
+        for (int i = 0; i < 5; i++) {
+            responses.add(greeter.greetMeAsync("asyn call" + i));
         }
-        
-        assertEquals(((TestExecutor)executor).getCount(), 5);
+        //wait for all the responses
+        for (Response<GreetMeResponse> resp : responses) {
+            resp.get();
+        }
+            
+        assertEquals(5, ((TestExecutor)executor).getCount());
     }
 
     
@@ -813,6 +829,15 @@ public class ClientServerTest extends AbstractBusClientServerTestBase {
         String realAddress = "http://localhost:9015/SoapContext/SoapPort";
         SOAPServiceBogusAddressTest service = new SOAPServiceBogusAddressTest();
         Greeter greeter = service.getSoapPort();
+        try {
+            greeter.greetMe("test");
+            fail("Should fail");
+        } catch (WebServiceException f) {
+            // expected
+        }
+
+        
+        
         BindingProvider bp = (BindingProvider)greeter;
         bp.getRequestContext().put(BindingProvider.ENDPOINT_ADDRESS_PROPERTY,
                                    realAddress);
@@ -873,7 +898,7 @@ public class ClientServerTest extends AbstractBusClientServerTestBase {
         // that would actually notice the difference. At least it ensures that 
         // specifying the property does not explode.
         Map<String, Object> jaxbContextProperties = new HashMap<String, Object>();
-        jaxbContextProperties.put(JAXBRIContext.DEFAULT_NAMESPACE_REMAP, "uri:ultima:thule");
+        jaxbContextProperties.put("com.sun.xml.bind.defaultNamespaceRemap", "uri:ultima:thule");
         dcf.setJaxbContextProperties(jaxbContextProperties);
         client = dcf.createClient(wsdlUrl, serviceName, portName);
         client.invoke("greetMe", "test");        
